Package: AntClassify
Type: Package
Title: Functional Guilds, Invasion Status, Endemism, and Rarity of Ants
Version: 0.2.1
Date: 2026-05-06
Authors@R: c(person(given = "Débora C. O.", family = "Gonçalves", role = c("aut", "cre"), email = "debora_cog@outlook.com"), person(given = "Nathalia S.", family = "Silva", role = "aut"), person(given = "Rony P. S.", family = "Almeida", role = "aut"), person(given = "Lívia P.", family = "Prado", role = "aut"), person(given = "Maria S. C.", family = "Morini", role = "aut"))
Description: Provides functions for the analysis of ant communities, aiming to
    standardize workflows in myrmecology. The package automates the assignment
    of species to functional guilds based on trophic strategies, feeding
    habits, and foraging behavior, using established classification frameworks
    (Silva et al., 2015 <doi:10.7476/9788574554419>; Silvestre et al., 2003
    <isbn:9588151236>; Delabie et al., 2000
    <https://www.researchgate.net/publication/44961742_Sampling_Ground-Dwelling_Ants_Case_Studies_from_the_World%27s_Rain_Forests>),
    and also includes a novel classification system implemented within the
    package, developed from ant species occurring in urban environments.
    It also includes routines to flag exotic species of Brazil (Vieira, 2025,
    unpublished master's thesis), identify endemic species (Silva et al., 2025
    <doi:10.37885/250920259>), and classify species rarity and rarity forms
    of the Atlantic Forest (Silva et al., 2024 <doi:10.1016/j.biocon.2024.110640>).
    The package reduces manual effort and improves reproducibility, supporting
    research and biodiversity management of Neotropical ant communities.
License: MIT + file LICENSE
URL: https://github.com/cogdebora/AntClassify
BugReports: https://github.com/cogdebora/AntClassify/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 3.5)
Imports: dplyr, ggplot2, jsonlite, magrittr, rlang, scales, stats,
        stringr, curl
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-06 15:27:57 UTC; 55119
Author: Débora C. O. Gonçalves [aut, cre],
  Nathalia S. Silva [aut],
  Rony P. S. Almeida [aut],
  Lívia P. Prado [aut],
  Maria S. C. Morini [aut]
Maintainer: Débora C. O. Gonçalves <debora_cog@outlook.com>
Repository: CRAN
Date/Publication: 2026-05-07 08:02:24 UTC
Built: R 4.6.0; ; 2026-05-07 11:43:44 UTC; unix

Package: AntClassify
Type: Package
Title: Functional Guilds, Invasion Status, Endemism, and Rarity of Ants
Version: 0.2.2
Date: 2026-06-17
Authors@R: c(person(given = "Débora C. O.", family = "Gonçalves", role = c("aut", "cre"), email = "debora_cog@outlook.com"), person(given = "Nathalia S.", family = "Silva", role = "aut"), person(given = "Rony P. S.", family = "Almeida", role = "aut"), person(given = "Lívia P.", family = "Prado", role = "aut"), person(given = "Maria S. C.", family = "Morini", role = "aut"))
Description: Provides functions for the analysis of ant communities, aiming to
    standardize workflows in myrmecology. The package automates the assignment
    of species to functional guilds based on trophic strategies, feeding
    habits, and foraging behavior, using established classification frameworks
    (Silva et al., 2015 <doi:10.7476/9788574554419>; Silvestre et al., 2003
    <isbn:9588151236>; Delabie et al., 2000
    <https://www.researchgate.net/publication/44961742_Sampling_Ground-Dwelling_Ants_Case_Studies_from_the_World%27s_Rain_Forests>),
    and also includes a novel classification system implemented within the
    package, developed from ant species occurring in urban environments.
    It also includes routines to flag exotic species of Brazil (Vieira, 2025,
    unpublished master's thesis), identify endemic species (Silva et al., 2025
    <doi:10.37885/250920259>), and classify species rarity and rarity forms
    of the Atlantic Forest (Silva et al., 2024 <doi:10.1016/j.biocon.2024.110640>).
    The package reduces manual effort and improves reproducibility, supporting
    research and biodiversity management of Neotropical ant communities.
License: MIT + file LICENSE
URL: https://github.com/cogdebora/AntClassify
BugReports: https://github.com/cogdebora/AntClassify/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 3.5)
Imports: dplyr, ggplot2, jsonlite, magrittr, rlang, scales, stats,
        stringr, curl
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-06-17 20:26:31 UTC; 55119
Author: Débora C. O. Gonçalves [aut, cre],
  Nathalia S. Silva [aut],
  Rony P. S. Almeida [aut],
  Lívia P. Prado [aut],
  Maria S. C. Morini [aut]
Maintainer: Débora C. O. Gonçalves <debora_cog@outlook.com>
Repository: CRAN
Date/Publication: 2026-06-17 20:50:02 UTC

# Generated by roxygen2: do not edit by hand

export(antclassify)
export(antclassify_community)
export(assign_guild_ants)
export(check_endemic_atlantic_ants)
export(check_exotic_ants)
export(check_rarity_atlantic_ants)
export(validate_species_names)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(magrittr,"%>%")
importFrom(rlang,sym)
importFrom(scales,percent_format)
importFrom(stats,reorder)
importFrom(stringr,str_split_fixed)
importFrom(stringr,str_wrap)
importFrom(utils,URLencode)
importFrom(utils,head)

# AntClassify

<!-- badges: start -->
[![R-CMD-check](https://github.com/cogdebora/AntClassify/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/cogdebora/AntClassify/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

AntClassify is an R package designed to **standardize ant community analyses**, particularly for Neotropical and Brazilian Atlantic Forest assemblages. It automates:

- Classification of species into **functional guilds** based on trophic strategies and foraging behavior. The package offers two approaches: (1) classification using established criteria from the literature (Delabie et al., 2000; Silvestre et al., 2003; Silva et al., 2015), and (2) a **built-in classification** derived from urban ant communities.
- Identification of **exotic species** recorded in Brazil (Vieira, 2025).
- Identification of **endemic species** of the Atlantic Forest (Silva et al., 2025).
- Classification of **rarity** based on geographic distribution and local abundance (Silva et al., 2024).

By automating these tasks, AntClassify reduces manual effort and increases reproducibility, making it a practical tool for researchers working with ant assemblages.

## Installation

You can install the **development version** of AntClassify from GitHub:

```r
# install.packages("remotes")
remotes::install_github("cogdebora/AntClassify")
```

Once the package is accepted on CRAN, you will also be able to install it with:

```r
install.packages("AntClassify")
```

## Example

Below is a reproducible example using a standardized test dataset:

```r
library(AntClassify)

# Create test dataset (same structure used in package tests)
ant_test_data <- data.frame(
  "Pheidole megacephala" = 10,
  "Strumigenys emmae" = 5,
  "Paratrechina longicornis" = 8,
  "Hypoponera leninei" = 3,
  "Camponotus fallatus" = 2,
  "Ectatomma brunneum" = 1,
  "Ectatomma permagnum" = 1,
  "Pheidole aberrans" = 1,
  "Pheidole fimbriata" = 1,
  "Pheidole obscurithorax" = 1,
  check.names = FALSE
)

# Run full pipeline
results <- antclassify(ant_test_data)

# View outputs
results$exotic$table
results$endemic$table
results$rarity$table

# Plot outputs
print(results$exotic$plot)
print(results$endemic$plot)
print(results$rarity$plot)
```

For more detailed examples and function documentation, see the package vignettes:

```r
vignette("AntClassify")
```

## Citation

If you use AntClassify in your research, please cite the following references:

- Silva, N. S., Maciel, E. A., Prado, L. P., Silva, O. G., Barbosa, D. A., Andrade-Silva, J., ... & Morini, M. S. (2024). Ant rarity and vulnerability in Brazilian Atlantic Forest fragments. *Biological Conservation*, 296, 110640. DOI: https://doi.org/10.1016/j.biocon.2024.110640

- Silva, N. S., Gonçalves, D. C. de O., Wazema, C. T., Barbosa, D. A., Prado, L. P. do, Andrade-Silva, J., Fernandes, T. T., Silva, R. R., & Morini, M. S. de C. (2025). Endemism and vulnerability of ants in the phytophysiognomies of the Brazilian Atlantic Forest. In *Brazilian Myrmecology: Exploring the World’s Richest Ant Fauna* (Cap. 16, pp. 371–394). Editora Científica Digital. DOI: https://doi.org/10.37885/250920259

- Vieira, V. B. (2024). *Quem são e onde estão as formigas exóticas do Brasil?* [Dissertação de Mestrado, Universidade Federal do Paraná]. Curitiba, PR, Brasil.

- Silvestre, R., Brandão, C. R. F., & Silva, R. R. (2003). Grupos funcionales de hormigas: el caso de los gremios del Cerrado. In F. Fernández (Ed.), *Introducción a las Hormigas de las Región Neotropical* (pp. 113–148). Instituto Alexander Von Humboldt.

- Silva, R. R., Silvestre, R., Brandão, C. R. F., Morini, M. S. C., & Delabie, J. H. C. (2015).  Grupos trófi cos e guildas em formigas poneromorfas. In: Delabie, Jacques H. C. et al.  *As formigas poneromorfas do Brasil*. Ilhéus: Editus, 2015. p. 163-179.

- Delabie, J. H. C., Agosti, D., & Nascimento, I. C. (2000). Litter ant communities of the Brazilian Atlantic rain
forest region. *Sampling Ground-dwelling Ants: case studies from the world’s rain forests. Curtin University of Technology School of Environmental Biology Bulletin*,v. 18.

Additionally, if you use the package itself, please cite:

- Gonçalves, D. C. O., et al. (2026). *AntClassify: An R package for ant community analysis* (Version 0.1.0) [Computer software].  
  https://github.com/cogdebora/AntClassify

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(AntClassify)

## -----------------------------------------------------------------------------
dados <- data.frame(
  Atta_sexdens = 50,
  Camponotus_atriceps = 40,
  Crematogaster_sp = 35,
  Cyphomyrmex_minutus = 30,
  Cyphomyrmex_rimosus = 28,
  Ectatomma_edentatum = 25,
  Heteroponera_mayri = 22,
  Holcoponera_striatula = 20,
  Monomorium_floricola = 18,
  Monomorium_pharaonis = 17,
  Pheidole_megacephala = 16,
  Strumigenys_emmae = 15,
  Strumigenys_rogeri = 14,
  Nylanderia_fulva = 13,
  Odontomachus_chelifer = 12,
  Oxyepoecus_reticulatus = 11,
  Pachycondyla_striata = 10,
  Apterostigma_serratum = 9,
  Brachymyrmex_delabiei = 8,
  Brachymyrmex_feitosai = 7,
  Camponotus_fallatus = 6,
  Camponotus_hermanni = 5,
  Camponotus_xanthogaster = 4,
  Pheidole_aberrans = 3,
  Pheidole_fimbriata = 3,
  Pheidole_obscurithorax = 2,
  Pheidole_subarmata = 2,
  Strumigenys_fridericimuelleri = 2,
  Heteroponera_inermis = 2,
  Oxyepoecus_browni = 2,
  Sphinctomyrmex_stali = 1,
  Strumigenys_sanctipauli = 1,
  Brachymyrmex_micromegas = 1,
  Camponotus_tripartitus = 1,
  Diaphoromyrma_sofiae = 1
)

colnames(dados) <- gsub("_", " ", colnames(dados))

dados

## -----------------------------------------------------------------------------
resultado <- antclassify(dados, validate = FALSE, plot = FALSE)

## -----------------------------------------------------------------------------
names(resultado)

head(resultado$guilds$table)
resultado$exotics
resultado$endemics
resultado$rarity

## -----------------------------------------------------------------------------
guilds <- assign_guild_ants(dados, validate = FALSE, plot = FALSE)

head(guilds$table)

## -----------------------------------------------------------------------------
exotics <- check_exotic_ants(dados, validate = FALSE, plot = FALSE)
exotics

## -----------------------------------------------------------------------------
endemics <- check_endemic_atlantic_ants(dados, validate = FALSE, plot = FALSE)
endemics

## -----------------------------------------------------------------------------
rarity <- check_rarity_atlantic_ants(dados, validate = FALSE, plot = FALSE)
rarity

## -----------------------------------------------------------------------------
data(ant_community)

# Run the pipeline on the built‑in dataset
res_com <- antclassify_community(ant_community, guild_col = "antclassify_guild",
                                 validate = FALSE)

# Abundance matrix (sites × guilds)
res_com$guild_abundance

# Guild richness per site
res_com$guild_richness

## -----------------------------------------------------------------------------
data(ant_community)
ant_community

## ----eval=FALSE---------------------------------------------------------------
# dados <- read.csv("data.csv", check.names = FALSE)

## ----eval=FALSE---------------------------------------------------------------
# dados <- read.table("data.txt", header = TRUE, sep = "\t", check.names = FALSE)

## ----eval=FALSE---------------------------------------------------------------
# # install.packages("readxl")
# library(readxl)
# 
# dados <- read_excel("data.xlsx")
# dados <- as.data.frame(dados)

## ----eval=FALSE---------------------------------------------------------------
# colnames(dados) <- gsub("_", " ", colnames(dados))

#' Validate Species Names Using GBIF API
#'
#' Checks species names against the GBIF taxonomic backbone. If an exact match is found,
#' the accepted name (or canonical name) is used. If no exact match is found, the
#' original name is kept and a warning is issued, indicating that the name may be
#' outdated or misspelled.
#'
#' @param comm A community matrix (rows = sites, columns = species).
#' @param verbose Logical; if TRUE, displays progress messages.
#' @param delay Numeric; seconds to wait between API calls (default 0.5).
#' @importFrom utils URLencode
#' @return A community matrix with updated column names (accepted names when available).
#' @export
#'
#' @examples
#' \dontrun{
#' data(ant_community)
#' comm_validated <- validate_species_names(ant_community, verbose = TRUE)
#' }
validate_species_names <- function(comm, verbose = TRUE, delay = 0.5) {
  if (verbose) message("Starting validation of species names via GBIF...")

  old_names <- colnames(comm)
  new_names <- character(length(old_names))
  unresolved <- character(0)

  for (i in seq_along(old_names)) {
    if (verbose) message("Processing [", i, "/", length(old_names), "]: ", old_names[i])

    name_encoded <- URLencode(old_names[i])
    url <- paste0("https://api.gbif.org/v1/species/match?verbose=false&name=", name_encoded)

    h <- curl::new_handle()
    curl::handle_setopt(h, timeout = 30, useragent = "AntClassify/1.0")

    res <- tryCatch(curl::curl_fetch_memory(url, handle = h), error = function(e) NULL)

    if (is.null(res)) {
      unresolved <- c(unresolved, old_names[i])
      new_names[i] <- old_names[i]
      next
    }

    texto <- rawToChar(res$content)
    dados <- tryCatch(jsonlite::fromJSON(texto), error = function(e) NULL)

    if (is.null(dados) || is.null(dados$matchType) || dados$matchType != "EXACT") {
      unresolved <- c(unresolved, old_names[i])
      new_names[i] <- old_names[i]
    } else {
      # Exact match: use the accepted name
      if (!is.null(dados$acceptedName)) {
        new_names[i] <- dados$acceptedName
      } else if (!is.null(dados$canonicalName)) {
        new_names[i] <- dados$canonicalName
      } else {
        new_names[i] <- old_names[i]
      }
    }

    Sys.sleep(delay)
  }

  colnames(comm) <- new_names

  if (length(unresolved) > 0) {
    warning(sprintf("%d species name(s) could not be validated by GBIF: %s",
                    length(unresolved), paste(unresolved, collapse = ", ")))
    if (verbose) {
      message("\n*** ATTENTION: The following names were not found or are no longer current:")
      for (p in unresolved) message("   - ", p)
      message("   Please verify these names manually before proceeding.")
    }
  } else {
    if (verbose) message("All species names were successfully validated (exact match in GBIF).")
  }

  return(comm)
}

#' @title Assign Functional Guilds for Ants
#' @description Classifies ants into functional guilds using four different ecological databases.
#' @param comm A community matrix where species are columns and samples are rows.
#' @param verbose Logical; if \code{TRUE}, displays progress messages.
#' @param plot Logical; if \code{TRUE}, displays guild proportion plots.
#' @param validate Logical; if \code{TRUE}, validates species names using GBIF before analysis.
#' @param delay Numeric; seconds to wait between GBIF API calls when \code{validate = TRUE}.
#' @importFrom dplyr group_by summarise mutate
#' @importFrom ggplot2 ggplot aes geom_col coord_flip labs theme_classic theme element_text element_blank element_line scale_y_continuous scale_x_discrete
#' @importFrom stringr str_split_fixed str_wrap
#' @importFrom stats reorder
#' @importFrom scales percent_format
#' @importFrom magrittr %>%
#' @importFrom rlang sym
#' @importFrom utils head
#' @return Invisibly returns a list with two elements:
#'   \item{table}{A data frame containing species, abundance, percentage, and guild assignments from each system.}
#'   \item{plots}{A list of four ggplot2 objects, one for each guild classification system.}
#' @export
assign_guild_ants <- function(comm, verbose = TRUE, plot = TRUE, validate = TRUE, delay = 0.5) {

  # Optional validation of species names using GBIF
  if (isTRUE(validate)) {
    comm <- validate_species_names(comm, verbose = verbose, delay = delay)
  }

  if (verbose) message("Step 1: Preparing community data...")

  # Convert community matrix to data frame and clean column names
  numeric_data <- as.data.frame(comm)
  colnames(numeric_data) <- trimws(gsub("[._]", " ", colnames(numeric_data)))

  # Calculate total abundance
  total_abundance <- sum(colSums(numeric_data, na.rm = TRUE))

  # Create species data frame
  species_df <- data.frame(
    species = colnames(numeric_data),
    abundance = colSums(numeric_data, na.rm = TRUE),
    stringsAsFactors = FALSE
  )
  species_df$percentage <- (species_df$abundance / total_abundance) * 100

  # Extract genus names from species names (first word only)
  genus_list <- stringr::str_split_fixed(species_df$species, pattern = " ", n = 2)[, 1]

  if (verbose) message("Step 2: Matching species to functional guilds...")

  # Assign guilds from each classification system
  species_df$antclassify_guild <- generic_db$guild[match(genus_list, generic_db$target)]
  species_df$silva_guild <- silva_db$guild[match(species_df$species, silva_db$target)]
  species_df$silva_guild[is.na(species_df$silva_guild)] <- silva_db$guild[match(genus_list[is.na(species_df$silva_guild)], silva_db$target)]
  species_df$delabie_guild <- delabie_db$guild[match(genus_list, delabie_db$target)]
  species_df$silvestre_guild <- silvestre_db$guild[match(species_df$species, silvestre_db$target)]
  species_df$silvestre_guild[is.na(species_df$silvestre_guild)] <- silvestre_db$guild[match(genus_list[is.na(species_df$silvestre_guild)], silvestre_db$target)]

  # Replace NA with "Unidentified Guild"
  guild_cols <- c("antclassify_guild", "silva_guild", "delabie_guild", "silvestre_guild")
  species_df[guild_cols] <- lapply(species_df[guild_cols], function(x) ifelse(is.na(x), "Unidentified Guild", x))

  # Show first 6 rows of results
  if (verbose) {
    message("\nGuild classification results (first 6 rows):")
    print(head(species_df))
  }

  if (verbose) message("Step 3: Generating plots...")

  # Internal function to create plots
  create_plot <- function(data, guild_col, title_text) {
    plot_data <- data %>%
      dplyr::group_by(!!rlang::sym(guild_col)) %>%
      dplyr::summarise(total = sum(abundance), .groups = "drop") %>%
      dplyr::mutate(prop = total / sum(total))

    ggplot2::ggplot(plot_data, ggplot2::aes(x = stats::reorder(!!rlang::sym(guild_col), prop), y = prop, fill = !!rlang::sym(guild_col))) +
      ggplot2::geom_col(color = "black", width = 0.7) +
      ggplot2::coord_flip() +
      ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
      ggplot2::scale_x_discrete(labels = function(x) stringr::str_wrap(x, width = 45)) +
      ggplot2::labs(title = title_text, x = "Functional Guild", y = "Proportion") +
      ggplot2::theme_classic() +
      ggplot2::theme(
        legend.position = "none",
        axis.text.y = ggplot2::element_text(size = 9),
        axis.text.x = ggplot2::element_text(size = 9),
        axis.title = ggplot2::element_text(size = 11),
        plot.title = ggplot2::element_text(hjust = 0.5, size = 12, face = "bold"),
        panel.grid = ggplot2::element_blank(),
        axis.line = ggplot2::element_line(color = "black")
      )
  }

  # Generate plots for each classification system
  p1 <- create_plot(species_df, "antclassify_guild", "Functional Guilds - AntClassify")
  p2 <- create_plot(species_df, "silva_guild", "Functional Guilds - Silva et al. (2015)")
  p3 <- create_plot(species_df, "delabie_guild", "Functional Guilds - Delabie et al. (2000)")
  p4 <- create_plot(species_df, "silvestre_guild", "Functional Guilds - Silvestre et al. (2003)")

  # Print plots if requested
  if (plot) {
    print(p1)
    print(p2)
    print(p3)
    print(p4)
  }

  # Short message with references (without full citations)
  if (verbose) {
    message("\nGuild classification sources: Delabie et al. (2000), Silvestre et al. (2003),\n",
            "Silva et al. (2015), and AntClassify internal database.\n",
            "Full citations are available in the package documentation: ?assign_guild_ants\n")
  }

  # Return results invisibly
  invisible(list(table = species_df, plots = list(p1, p2, p3, p4)))
}

#' @title Identify Endemic Ant Species (Atlantic Forest)
#' @description Checks a community matrix for ant species endemic to the Brazilian Atlantic Forest based on Silva et al. (2025).
#' @param comm A community matrix where species are columns and samples are rows.
#' @param verbose Logical; if \code{TRUE}, displays progress messages.
#' @param plot Logical; if \code{TRUE}, displays a plot (type controlled by \code{plot_type}).
#' @param plot_type Character; type of plot to display. \code{"status"} (default) shows a bar plot comparing
#'   endemic vs. other species abundance proportions. \code{"species"} shows a bar plot of individual endemic
#'   species abundances as a proportion of the total community.
#' @param validate Logical; if \code{TRUE}, validates species names using GBIF before analysis.
#' @param delay Numeric; seconds to wait between GBIF API calls when \code{validate = TRUE}.
#' @importFrom dplyr group_by summarise mutate
#' @importFrom ggplot2 ggplot aes geom_col scale_y_continuous scale_fill_manual labs theme_classic theme element_text element_blank element_line
#' @importFrom scales percent_format
#' @importFrom stats reorder
#' @return Invisibly returns a list with two elements:
#'   \item{table}{A data frame containing endemic species detected, with columns species, abundance, and percentage.}
#'   \item{plot}{A ggplot2 object.}
#' @export
check_endemic_atlantic_ants <- function(comm, verbose = TRUE, plot = TRUE,
                                        plot_type = c("status", "species"),
                                        validate = TRUE, delay = 0.5) {

  plot_type <- match.arg(plot_type)

  if (isTRUE(validate)) {
    comm <- validate_species_names(comm, verbose = verbose, delay = delay)
  }

  if (verbose) {
    message("\n**********************************************************************************")
    message("ATTENTION: This function identifies endemic species of the BRAZILIAN ATLANTIC FOREST.")
    message("If your data collection did not occur within this biome, this analysis may not")
    message("be appropriate for your study.")
    message("**********************************************************************************\n")
  }

  if (verbose) message("Step 1: Preparing community data...")

  # Internal endemic species list (Atlantic Forest)
  endemic_list <- c(
    "Acanthostichus flexuosus", "Apterostigma serratum", "Brachymyrmex delabiei",
    "Brachymyrmex feitosai", "Camponotus fallatus", "Camponotus hermanni",
    "Camponotus xantogaster", "Carebara nuda", "Carebara pilosa",
    "Crematogaster montana", "Crematogaster stigmatica", "Discothyrea bobi",
    "Eurhopalothrix depressa", "Fulakora cleae", "Heteroponera angulata",
    "Hylomyrma villemantae", "Hypoponera leninei", "Leptanilloides atlanticus",
    "Leptogenys academica", "Leptogenys carioca", "Monomorium delabiei",
    "Mycetagroicus urbanus", "Mycocepurus castrator", "Myrmelachista reticulata",
    "Neoponera concava", "Neoponera latinoda", "Oxyepoecus vivax",
    "Pheidole abakytan", "Pheidole borgmeieri", "Pheidole brunnescens",
    "Pheidole cangussu", "Pheidole cardinalis", "Pheidole curupira",
    "Pheidole eidmanni", "Pheidole foederalis", "Pheidole moseni",
    "Pheidole praeses", "Pheidole protaxi", "Poneracantha wilsoni",
    "Procryptocerus curvistriatus", "Procryptocerus lenkoi", "Pseudomyrmex goeldii",
    "Rhopalothrix plaumanni", "Rogeria lacertosa", "Sphinctomyrmex schoerederi",
    "Strumigenys dentinasis", "Strumigenys substricta", "Tapinoma gibbosum",
    "Typhlomyrmex lavra"
  )

  # Prepare community data
  numeric_data <- as.data.frame(comm)
  clean_names <- trimws(gsub("_", " ", gsub("\\.", " ", colnames(numeric_data))))
  colnames(numeric_data) <- clean_names

  total_abundance <- sum(colSums(numeric_data, na.rm = TRUE))

  # Create species data frame
  species_df <- data.frame(
    species = colnames(numeric_data),
    abundance = as.numeric(colSums(numeric_data, na.rm = TRUE)),
    stringsAsFactors = FALSE
  )

  species_df$percentage <- (species_df$abundance / total_abundance) * 100
  species_df$status <- ifelse(species_df$species %in% endemic_list, "Endemic (AF)", "Other/Not Listed")

  if (verbose) message("Step 2: Generating results...")

  # Prepare data for status plot
  plot_data <- dplyr::group_by(species_df, status)
  plot_data <- dplyr::summarise(plot_data, total = sum(abundance), .groups = "drop")
  plot_data <- dplyr::mutate(plot_data, prop = total / sum(total))

  # Identify endemic species
  endemic_species <- species_df[species_df$status == "Endemic (AF)", ]
  rownames(endemic_species) <- NULL

  # --- Generate plot based on plot_type ---
  p <- NULL

  if (plot_type == "status") {
    p <- ggplot2::ggplot(plot_data, ggplot2::aes(x = stats::reorder(status, prop), y = prop, fill = status)) +
      ggplot2::geom_col(color = "black", width = 0.7) +
      ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
      ggplot2::scale_fill_manual(values = c("Endemic (AF)" = "#2c7bb6", "Other/Not Listed" = "#abd9e9")) +
      ggplot2::labs(
        title = "Proportion of Atlantic Forest Endemic Species",
        x = "Status",
        y = "Proportion"
      ) +
      ggplot2::theme_classic() +
      ggplot2::theme(
        legend.position = "none",
        axis.text.x = ggplot2::element_text(size = 10),
        axis.text.y = ggplot2::element_text(size = 9),
        axis.title = ggplot2::element_text(size = 11),
        plot.title = ggplot2::element_text(hjust = 0.5, size = 12, face = "bold"),
        panel.grid = ggplot2::element_blank(),
        axis.line = ggplot2::element_line(color = "black")
      )
  } else { # plot_type == "species"
    if (nrow(endemic_species) > 0) {
      endemic_plot_data <- endemic_species
      endemic_plot_data$prop_community <- endemic_plot_data$abundance / total_abundance

      p <- ggplot2::ggplot(
        endemic_plot_data,
        ggplot2::aes(x = stats::reorder(species, -prop_community), y = prop_community)
      ) +
        ggplot2::geom_col(fill = "#2c7bb6", color = "black", width = 0.7) +
        ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 0.1)) +
        ggplot2::labs(
          title = "Endemic Species of the Atlantic Forest",
          x = NULL,
          y = "Proportion of Total Community"
        ) +
        ggplot2::theme_classic() +
        ggplot2::theme(
          axis.text.x = ggplot2::element_text(angle = 45, hjust = 1, face = "italic", size = 9),
          axis.text.y = ggplot2::element_text(size = 9),
          axis.title = ggplot2::element_text(size = 11),
          plot.title = ggplot2::element_text(hjust = 0.5, size = 12, face = "bold"),
          panel.grid = ggplot2::element_blank(),
          axis.line = ggplot2::element_line(color = "black"),
          legend.position = "none"
        )
    } else {
      p <- ggplot2::ggplot() +
        ggplot2::annotate("text", x = 1, y = 1, label = "No endemic species detected") +
        ggplot2::theme_void()
    }
  }

  if (plot) print(p)

  # Short message with references (without full citations)
  if (verbose) {
    message("\n********************************************************************************")
    if (nrow(endemic_species) > 0) {
      message("ENDEMIC SPECIES DETECTED (ATLANTIC FOREST):")
      print(endemic_species[, c("species", "abundance", "percentage")])
    } else {
      message("No species from the Atlantic Forest endemic list were detected in this community.")
    }
    message("\nDATA SOURCE:")
    message("Silva, N. S., Goncalves, D. C. de O., Wazema, C. T., Barbosa, D. A., Prado, L. P. do,")
    message("Andrade-Silva, J., Fernandes, T. T., Silva, R. R., & Morini, M. S. de C. (2025).")
    message("'Endemism and vulnerability of ants in the phytophysiognomies of the Brazilian")
    message("Atlantic Forest'. In: Brazilian Myrmecology: Exploring the World's Richest Ant Fauna")
    message("(Chapter 16). Editora Cientifica Digital. DOI: 10.37885/250920259.")
    message("Full reference available in the package documentation: ?check_endemic_atlantic_ants")
    message("********************************************************************************")
  }

  invisible(list(table = endemic_species, plot = p))
}

#' @title Classify Ant Communities Across Multiple Sites
#' @description Applies the AntClassify pipeline to each site (row) of a community matrix
#' and returns aggregated guild abundance and richness matrices.
#'
#' @param comm A community matrix with sites as rows and species as columns.
#'   Species names must match the nomenclature used in the internal databases.
#' @param guild_col Character string giving the name of the guild column to use
#'   for aggregation. Must be one of \code{"antclassify_guild"}, \code{"silva_guild"},
#'   \code{"delabie_guild"}, or \code{"silvestre_guild"}. Default is
#'   \code{"antclassify_guild"}.
#' @param ... Additional arguments passed to \code{\link{assign_guild_ants}} (for
#'   example, \code{validate}, \code{delay}). Note that \code{plot} is always set
#'   to \code{FALSE} inside this function to avoid displaying one plot per site.
#'
#' @return A list with three components:
#'   \item{by_site}{A list of length equal to \code{nrow(comm)}. Each element
#'     contains the full output of \code{\link{assign_guild_ants}} for the
#'     corresponding site.}
#'   \item{guild_abundance}{A matrix of guild abundances (sites × guilds).}
#'   \item{guild_richness}{A numeric vector of length \code{nrow(comm)} giving
#'     the number of distinct guilds found at each site.}
#'
#' @export
#'
#' @examples
#' # Small community matrix with two sites and six species
#' comm <- matrix(c(5, 0, 2, 0, 1, 3,
#'                  2, 4, 0, 2, 0, 0),
#'                nrow = 2, byrow = TRUE,
#'                dimnames = list(c("Site1", "Site2"),
#'                                c("Atta sexdens", "Camponotus atriceps",
#'                                  "Pheidole megacephala", "Wasmannia auropunctata",
#'                                  "Solenopsis saevissima", "Nylanderia fulva")))
#'
#' # Run the classification (validate = FALSE to avoid GBIF calls in examples)
#' results <- antclassify_community(comm, guild_col = "antclassify_guild",
#'                                  validate = FALSE)
#' results$guild_abundance
#' results$guild_richness
#' @export
antclassify_community <- function(comm, guild_col = "antclassify_guild", ...) {

  # Input validation
  if (!is.data.frame(comm) && !is.matrix(comm)) {
    stop("'comm' must be a data frame or matrix with sites as rows and species as columns.")
  }

  valid_guilds <- c("antclassify_guild", "silva_guild", "delabie_guild", "silvestre_guild")
  if (!guild_col %in% valid_guilds) {
    stop("'guild_col' must be one of: ", paste(valid_guilds, collapse = ", "))
  }

  # Coerce to matrix to ensure consistent behavior
  comm <- as.matrix(comm)

  # Row names
  if (is.null(rownames(comm))) {
    rownames(comm) <- paste0("Site_", seq_len(nrow(comm)))
  }

  n_sites <- nrow(comm)

  # Process each site
  process_site <- function(i) {
    site_comm <- comm[i, , drop = FALSE]
    # Remove species absent from this site
    present <- colSums(site_comm, na.rm = TRUE) > 0
    site_comm <- site_comm[, present, drop = FALSE]

    if (ncol(site_comm) == 0) {
      # Empty site -> return empty structures
      empty_table <- data.frame(
        species = character(),
        abundance = numeric(),
        antclassify_guild = character(),
        silva_guild = character(),
        delabie_guild = character(),
        silvestre_guild = character(),
        percentage = numeric(),
        stringsAsFactors = FALSE
      )
      return(list(
        result = list(table = empty_table, plots = list()),
        guild_aggregated = data.frame(Guild = character(), abundance = numeric()),
        richness = 0L
      ))
    }

    # Suppress plot printing inside assign_guild_ants
    result <- assign_guild_ants(site_comm, plot = FALSE, ...)
    species_table <- result$table

    # Aggregate by chosen guild column
    guild_aggregated <- stats::aggregate(
      species_table$abundance,
      by = list(Guild = species_table[[guild_col]]),
      FUN = sum
    )
    colnames(guild_aggregated)[2] <- "abundance"

    list(
      result = result,
      guild_aggregated = guild_aggregated,
      richness = nrow(guild_aggregated)
    )
  }

  site_results <- lapply(seq_len(n_sites), process_site)

  # Build output components
  by_site <- lapply(site_results, function(x) x$result)
  guild_richness <- vapply(site_results, function(x) x$richness, integer(1))

  # Gather all guild names
  all_guilds <- unique(unlist(
    lapply(site_results, function(x) x$guild_aggregated$Guild)
  ))

  # Build abundance matrix (sites x guilds)
  guild_abundance <- matrix(
    0,
    nrow = n_sites,
    ncol = length(all_guilds),
    dimnames = list(rownames(comm), all_guilds)
  )

  for (i in seq_len(n_sites)) {
    guild_data <- site_results[[i]]$guild_aggregated
    if (nrow(guild_data) > 0) {
      guild_abundance[i, guild_data$Guild] <- guild_data$abundance
    }
  }

  list(
    by_site = by_site,
    guild_abundance = guild_abundance,
    guild_richness = guild_richness
  )
}

library(testthat)
library(AntClassify)

# Force non-interactive mode to prevent "Press Enter" prompts during CRAN checks
options(interactive = FALSE)

# Mock readline globally to ensure automated tests do not hang
assignInNamespace("readline", function(...) "", ns = "base")

# Execute all tests in the package
test_check("AntClassify")

# Restore readline to its original state (safety measure)
assignInNamespace("readline", base::readline, ns = "base")

#' @title Identify Exotic Ant Species (Brazil)
#' @description Checks a community matrix for known exotic ant species in Brazil sourced from Vieira (2025).
#' @param comm A community matrix where species are columns and samples are rows.
#' @param verbose Logical; if \code{TRUE}, displays progress messages.
#' @param plot Logical; if \code{TRUE}, displays a plot (type controlled by \code{plot_type}).
#' @param plot_type Character; type of plot to display. \code{"status"} (default) shows a bar plot comparing
#'   exotic vs. native abundance proportions. \code{"species"} shows a bar plot of individual exotic species
#'   abundances as a proportion of the total community.
#' @param validate Logical; if \code{TRUE}, validates species names using GBIF before analysis.
#' @param delay Numeric; seconds to wait between GBIF API calls when \code{validate = TRUE}.
#' @importFrom dplyr group_by summarise mutate
#' @importFrom ggplot2 ggplot aes geom_col scale_y_continuous scale_fill_manual labs theme_classic theme element_text element_blank element_line
#' @importFrom scales percent_format
#' @importFrom stats reorder
#' @return Invisibly returns a list with two elements:
#'   \item{table}{A data frame containing exotic species detected, with columns species, abundance, and percentage.}
#'   \item{plot}{A ggplot2 object.}
#' @export
check_exotic_ants <- function(comm, verbose = TRUE, plot = TRUE, plot_type = c("status", "species"),
                              validate = TRUE, delay = 0.5) {

  plot_type <- match.arg(plot_type)

  if (isTRUE(validate)) {
    comm <- validate_species_names(comm, verbose = verbose, delay = delay)
  }

  if (verbose) message("Step 1: Preparing community data...")

  # Internal exotic species list (Brazil)
  exotic_list <- c(
    "Tapinoma melanocephalum", "Technomyrmex vitiensis", "Paratrechina longicornis",
    "Cardiocondyla emeryi", "Cardiocondyla minutior", "Cardiocondyla obscurior",
    "Cardiocondyla wroughtonii", "Monomorium floricola", "Monomorium pharaonis",
    "Pheidole megacephala", "Strumigenys emmae", "Strumigenys rogeri",
    "Tetramorium bicarinatum", "Tetramorium caldarium", "Tetramorium lanuginosum",
    "Tetramorium lucayanum", "Tetramorium simillimum", "Trichomyrmex destructor",
    "Leptogenys maxillosa"
  )

  # Prepare community data
  numeric_data <- as.data.frame(comm)
  clean_names <- trimws(gsub("_", " ", gsub("\\.", " ", colnames(numeric_data))))
  colnames(numeric_data) <- clean_names

  total_abundance <- sum(colSums(numeric_data, na.rm = TRUE))

  # Create species data frame
  species_df <- data.frame(
    species = colnames(numeric_data),
    abundance = as.numeric(colSums(numeric_data, na.rm = TRUE)),
    stringsAsFactors = FALSE
  )

  species_df$percentage <- (species_df$abundance / total_abundance) * 100
  species_df$origin <- ifelse(species_df$species %in% exotic_list, "Exotic", "Native/Not Listed")

  if (verbose) message("Step 2: Generating results...")

  # Prepare data for status plot
  plot_data <- dplyr::group_by(species_df, origin)
  plot_data <- dplyr::summarise(plot_data, total = sum(abundance), .groups = "drop")
  plot_data <- dplyr::mutate(plot_data, prop = total / sum(total))

  # Identify exotic species
  exotic_species <- species_df[species_df$origin == "Exotic", ]
  rownames(exotic_species) <- NULL

  # --- Generate plot based on plot_type ---
  p <- NULL

  if (plot_type == "status") {
    p <- ggplot2::ggplot(plot_data, ggplot2::aes(x = stats::reorder(origin, prop), y = prop, fill = origin)) +
      ggplot2::geom_col(color = "black", width = 0.7) +
      ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
      ggplot2::scale_fill_manual(values = c("Exotic" = "#d95f02", "Native/Not Listed" = "#1b9e77")) +
      ggplot2::labs(
        title = "Proportion of Exotic vs. Native Species",
        x = "Status",
        y = "Proportion"
      ) +
      ggplot2::theme_classic() +
      ggplot2::theme(
        legend.position = "none",
        axis.text.x = ggplot2::element_text(size = 10),
        axis.text.y = ggplot2::element_text(size = 9),
        axis.title = ggplot2::element_text(size = 11),
        plot.title = ggplot2::element_text(hjust = 0.5, size = 12, face = "bold"),
        panel.grid = ggplot2::element_blank(),
        axis.line = ggplot2::element_line(color = "black")
      )
  } else { # plot_type == "species"
    if (nrow(exotic_species) > 0) {
      exotic_plot_data <- exotic_species
      exotic_plot_data$prop_community <- exotic_plot_data$abundance / total_abundance

      p <- ggplot2::ggplot(
        exotic_plot_data,
        ggplot2::aes(x = stats::reorder(species, -prop_community), y = prop_community)
      ) +
        ggplot2::geom_col(fill = "#d95f02", color = "black", width = 0.7) +
        ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 0.1)) +
        ggplot2::labs(
          title = "Exotic Species Detected",
          x = NULL,
          y = "Proportion of Total Community"
        ) +
        ggplot2::theme_classic() +
        ggplot2::theme(
          axis.text.x = ggplot2::element_text(angle = 45, hjust = 1, face = "italic", size = 9),
          axis.text.y = ggplot2::element_text(size = 9),
          axis.title = ggplot2::element_text(size = 11),
          plot.title = ggplot2::element_text(hjust = 0.5, size = 12, face = "bold"),
          panel.grid = ggplot2::element_blank(),
          axis.line = ggplot2::element_line(color = "black"),
          legend.position = "none"
        )
    } else {
      p <- ggplot2::ggplot() +
        ggplot2::annotate("text", x = 1, y = 1, label = "No exotic species detected") +
        ggplot2::theme_void()
    }
  }

  if (plot) print(p)

  # Short message with references (without full citations)
  if (verbose) {
    message("\n********************************************************************************")
    if (nrow(exotic_species) > 0) {
      message("EXOTIC SPECIES DETECTED:")
      print(exotic_species[, c("species", "abundance", "percentage")])
    } else {
      message("No exotic species from the target list were detected in this community.")
    }
    message("\nDATA SOURCE:")
    message("Vieira, V. B. (2025). 'Quem s\u00e3o e onde est\u00e3o as formigas ex\u00f3ticas do Brasil?'")
    message("Master's thesis, Universidade Federal do Paran\u00e1, Curitiba, Brazil.")
    message("Full reference available in the package documentation: ?check_exotic_ants")
    message("********************************************************************************")
  }

  invisible(list(table = exotic_species, plot = p))
}

#' AntClassify Full Ecological Pipeline
#'
#' Runs all ecological classification functions of the package.
#'
#' @param comm Community matrix (samples x species). Species names as columns, samples as rows.
#' @param verbose Logical; if TRUE, displays progress messages.
#' @param plot Logical; if TRUE, displays guild proportion plots (passed to assign_guild_ants).
#' @param validate Logical; if TRUE, validates species names using GBIF.
#' @param delay Numeric; seconds between API calls (if validate = TRUE).
#' @return A list containing results from all analyses (guilds, exotic, endemic, rarity).
#' @export
#'
#' @examples
#' \dontrun{
#' # Load the built-in example dataset
#' data(ant_community)
#'
#' # Run the full pipeline (validation disabled for speed)
#' results <- antclassify(ant_community, validate = FALSE, plot = FALSE)
#'
#' # Inspect the results
#' names(results)
#' head(results$guilds$table)
#' results$exotic$table
#' results$endemic$table
#' results$rarity$table
#' }
antclassify <- function(comm, verbose = TRUE, plot = TRUE, validate = TRUE, delay = 0.5) {

  if (verbose) message("*************************************************")
  if (verbose) message("Starting AntClassify")
  if (verbose) message("*************************************************")

  if (!is.data.frame(comm) && !is.matrix(comm)) {
    stop("Error: input must be a data.frame or matrix.")
  }

  # Convert to data.frame if matrix
  comm <- as.data.frame(comm)

  if (!all(sapply(comm, is.numeric))) {
    stop("Error: all columns should be numerical (species abundance).")
  }

  results <- list()

  # Validate species names if requested
  if (isTRUE(validate)) {
    if (verbose) message("\n>>> Validating species names via GBIF")
    comm <- validate_species_names(comm, verbose = verbose, delay = delay)
  }

  # Run guild classification (validation already done)
  if (verbose) message("\n>>> Running guild classification")
  results$guilds <- assign_guild_ants(comm, verbose = verbose, plot = plot, validate = FALSE)

  # Run exotic check
  if (verbose) message("\n>>> Checking exotic species")
  results$exotic <- check_exotic_ants(comm, verbose = verbose, plot = plot)

  # Run endemic check
  if (verbose) message("\n>>> Checking Atlantic Forest endemic species")
  results$endemic <- check_endemic_atlantic_ants(comm, verbose = verbose, plot = plot)

  # Run rarity check
  if (verbose) message("\n>>> Checking Atlantic Forest rarity patterns")
  results$rarity <- check_rarity_atlantic_ants(comm, verbose = verbose, plot = plot)

  if (verbose) message("\n***********************************************")
  if (verbose) message("AntClassify finished successfully")
  if (verbose) message("*************************************************")

  return(invisible(results))
}

library(testthat)
library(AntClassify)

# 1. Prepare standardized test data based on validated species lists
# These frequencies are designed to trigger specific results in each function
ant_test_data <- data.frame(
  # Exotic species (Expected: 3)
  "Pheidole megacephala" = 10,
  "Strumigenys emmae" = 5,
  "Paratrechina longicornis" = 8,
  # Endemic species (Expected: 2)
  "Hypoponera leninei" = 3,
  "Camponotus fallatus" = 2,
  # Rare species (Expected: 5)
  "Ectatomma brunneum" = 1,
  "Ectatomma permagnum" = 1,
  "Pheidole aberrans" = 1,
  "Pheidole fimbriata" = 1,
  "Pheidole obscurithorax" = 1,
  check.names = FALSE
)

test_that("AntClassify identifies and filters species correctly", {

  # Execute the full ecological pipeline
  results <- antclassify(ant_test_data)

  # VALIDATION: Exotic Ants (Vieira 2025)
  # Expecting exactly 3 species detected and filtered
  expect_equal(nrow(results$exotic$table), 3)
  expect_true("Pheidole megacephala" %in% results$exotic$table$species)

  # VALIDATION: Endemic Atlantic Forest Ants (Silva et al. 2025)
  # Expecting exactly 2 species detected and filtered
  expect_equal(nrow(results$endemic$table), 2)
  expect_true("Hypoponera leninei" %in% results$endemic$table$species)

  # VALIDATION: Rarity Forms (Silva et al. 2024)
  # Expecting exactly 5 rare species detected and filtered
  expect_equal(nrow(results$rarity$table), 5)
  expect_true("Ectatomma permagnum" %in% results$rarity$table$species)
})

test_that("AntClassify generates and displays visual outputs", {

  # Execute the pipeline to retrieve plot objects
  results <- antclassify(ant_test_data)

  # Verify if plot objects were correctly created as ggplot objects
  expect_s3_class(results$exotic$plot, "ggplot")
  expect_s3_class(results$endemic$plot, "ggplot")
  expect_s3_class(results$rarity$plot, "ggplot")


  print(results$exotic$plot)
  print(results$endemic$plot)
  print(results$rarity$plot)
})

#' @title Identify Ant Rarity Forms (Atlantic Forest)
#' @description Checks a community matrix for ant rarity forms in the Brazilian Atlantic Forest based on Silva et al. (2024).
#' @param comm A community matrix where species are columns and samples are rows.
#' @param verbose Logical; if \code{TRUE}, displays progress messages.
#' @param plot Logical; if \code{TRUE}, displays a plot (type controlled by \code{plot_type}).
#' @param plot_type Character; type of plot to display. \code{"status"} (default) shows a bar plot of rarity form
#'   abundance proportions. \code{"species"} shows a bar plot of individual rare species abundances as a proportion
#'   of the total community, colored by rarity form.
#' @param validate Logical; if \code{TRUE}, validates species names using GBIF before analysis.
#' @param delay Numeric; seconds to wait between GBIF API calls when \code{validate = TRUE}.
#' @importFrom dplyr group_by summarise mutate
#' @importFrom ggplot2 ggplot aes geom_col labs theme_classic theme element_text element_blank element_line scale_y_continuous guides guide_legend
#' @importFrom scales percent_format
#' @importFrom stats reorder
#' @return Invisibly returns a list with two elements:
#'   \item{table}{A data frame containing rare species detected, with columns species, rarity_form, abundance, and percentage.}
#'   \item{plot}{A ggplot2 object.}
#' @export
check_rarity_atlantic_ants <- function(comm, verbose = TRUE, plot = TRUE,
                                       plot_type = c("status", "species"),
                                       validate = TRUE, delay = 0.5) {

  plot_type <- match.arg(plot_type)

  if (isTRUE(validate)) {
    comm <- validate_species_names(comm, verbose = verbose, delay = delay)
  }

  if (verbose) {
    message("\n********************************************************************************")
    message("ATTENTION:")
    message("This function identifies rare ant species and their rarity forms.")
    message("This classification is specific to the Brazilian Atlantic Forest and")
    message("may not be appropriate for other biomes.")
    message("********************************************************************************\n")
  }

  if (verbose) message("Step 1: Preparing community data and rarity database...")

  # Internal rarity database
  rarity_db <- data.frame(
    species = c(
      "Acanthoponera mucronata", "Acropyga guianensis", "Alfaria minuta", "Brachymyrmex coactus",
      "Camponotus trapezoideus", "Ectatomma tuberculatum", "Eurhopalothrix bruchi", "Leptogenys unistimulosa",
      "Mayaponera arhuaca", "Megalomyrmex incisus", "Neivamyrmex punctaticeps", "Oxyepoecus longicephalus",
      "Oxyepoecus reticulatus", "Procryptocerus convergens", "Pseudomyrmex tenuis", "Pseudoponera gilberti",
      "Pseudoponera stigma", "Strumigenys cultrigera", "Strumigenys gytha", "Strumigenys precava",
      "Strumigenys schulzi", "Strumigenys smithii", "Thaumatomyrmex atrox", "Wasmannia scrobifera",
      "Apterostigma acre", "Camponotus atriceps", "Camponotus blandus", "Camponotus crassus",
      "Camponotus lespesii", "Camponotus senex", "Crematogaster arata", "Crematogaster rochai",
      "Cyphomyrmex major", "Dorymyrmex brunneus", "Hypoponera distinguenda", "Linepithema leucomelas",
      "Linepithema micans", "Mycocepurus goeldii", "Mycocepurus smithii", "Myrmelachista arthuri",
      "Myrmelachista catharinae", "Myrmelachista ruzskyi", "Neivamyrmex pseudops", "Ochetomyrmex subpolitus",
      "Octostruma balzani", "Oxyepoecus plaumanni", "Pheidole aberrans", "Pheidole fimbriata",
      "Pheidole obscurithorax", "Pheidole subarmata", "Pogonomyrmex naegelii", "Pseudomyrmex gracilis",
      "Pseudomyrmex phyllophilus", "Pseudomyrmex schuppi", "Solenopsis geminata", "Thaumatomyrmex mutilatus",
      "Typhlomyrmex rogenhoferi", "Wasmannia rochai", "Acropyga xexsanguis", "Acropyga panamensis",
      "Basiceros convexiceps", "Brachymyrmex patagonicus", "Camponotus canescens", "Cephalotes angustus",
      "Crematogaster corticicola", "Cylindromyrmex brasiliensis", "Cyphomyrmex transversus", "Eciton quadriglume",
      "Ectatomma brunneum", "Ectatomma permagnum", "Eurhopalothrix gravis", "Gnamptogenys haenschi",
      "Gnamptogenys interrupta", "Gnamptogenys sulcata", "Holcoponera pleurodon", "Labidus mars",
      "Linepithema pulex", "Mycetarotes carinatus", "Mycetarotes parallelus", "Mycetomoellerius urichii",
      "Mycetophylax olitor", "Neoponera unidentata", "Nesomyrmex echinatinodis", "Oxyepoecus bruchi",
      "Oxyepoecus vezenyii", "Procryptocerus regularis", "Pseudomyrmex oculatus", "Rasopone lunaris",
      "Rogeria subarmata", "Strumigenys carinithorax", "Strumigenys epelys", "Strumigenys fridericimuelleri",
      "Brachymyrmex feitosai", "Heteroponera inermis", "Lachnomyrmex victori", "Megalomyrmex iheringi",
      "Megalomyrmex myops", "Mycetophylax plaumanni", "Oxyepoecus crassinodus", "Strumigenys splendens",
      "Typhlomyrmex reichenspergeri", "Phalacromyrmex fugax", "Poneracantha lucaris", "Strumigenys dapsilis",
      "Strumigenys reticeps", "Lachnomyrmex nordestinus", "Megalomyrmex pusillus", "Oxyepoecus browni",
      "Sphinctomyrmex stali", "Strumigenys sanctipauli", "Brachymyrmex micromegas", "Camponotus tripartitus",
      "Diaphoromyrma sofiae", "Eurhopalothrix speciosa", "Heteroponera robusta", "Mycetarotes senticosus",
      "Mycetophylax auritus", "Neoponera metanotalis", "Strumigenys dentinasis", "Strumigenys substricta"
    ),
    rarity_form = c(
      rep("Form 1", 24), rep("Form 2", 34), rep("Form 3", 34), rep("Form 4", 9),
      rep("Form 5", 4), rep("Form 6", 5), rep("Form 7", 10)
    ),
    stringsAsFactors = FALSE
  )

  # Prepare community data
  numeric_data <- as.data.frame(comm)
  clean_names <- trimws(gsub("_", " ", gsub("\\.", " ", colnames(numeric_data))))
  colnames(numeric_data) <- clean_names

  rarity_db$species <- trimws(rarity_db$species)

  total_abundance <- sum(colSums(numeric_data, na.rm = TRUE))

  # Create species data frame
  species_df <- data.frame(
    species = colnames(numeric_data),
    abundance = as.numeric(colSums(numeric_data, na.rm = TRUE)),
    stringsAsFactors = FALSE
  )

  # Merge with rarity database
  species_df <- merge(species_df, rarity_db, by = "species", all.x = TRUE)
  species_df$rarity_form[is.na(species_df$rarity_form)] <- "Common"

  species_df$percentage <- (species_df$abundance / total_abundance) * 100

  if (verbose) message("Step 2: Generating results...")

  # Prepare data for status plot
  plot_data <- dplyr::group_by(species_df, rarity_form)
  plot_data <- dplyr::summarise(plot_data, total = sum(abundance), .groups = "drop")
  plot_data <- dplyr::mutate(plot_data, prop = total / sum(total))

  # Identify rare species (excluding "Common")
  rare_species <- species_df[species_df$rarity_form != "Common", ]
  rownames(rare_species) <- NULL

  # --- Generate plot based on plot_type ---
  p <- NULL

  if (plot_type == "status") {
    p <- ggplot2::ggplot(plot_data, ggplot2::aes(x = stats::reorder(rarity_form, prop), y = prop, fill = rarity_form)) +
      ggplot2::geom_col(color = "black", width = 0.7) +
      ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
      ggplot2::labs(
        title = "Ant Rarity Forms Distribution",
        x = "Rarity Classification",
        y = "Proportion",
        fill = NULL  # Remove o título da legenda
      ) +
      ggplot2::theme_classic() +
      ggplot2::theme(
        legend.position = "bottom",
        axis.text.x = ggplot2::element_text(size = 10),
        axis.text.y = ggplot2::element_text(size = 9),
        axis.title = ggplot2::element_text(size = 11),
        plot.title = ggplot2::element_text(hjust = 0.5, size = 12, face = "bold"),
        panel.grid = ggplot2::element_blank(),
        axis.line = ggplot2::element_line(color = "black"),
        legend.title = ggplot2::element_blank()  # Garantia extra
      )
  } else { # plot_type == "species"
    if (nrow(rare_species) > 0) {
      rare_plot_data <- rare_species
      rare_plot_data$prop_community <- rare_plot_data$abundance / total_abundance

      p <- ggplot2::ggplot(
        rare_plot_data,
        ggplot2::aes(x = stats::reorder(species, -prop_community), y = prop_community, fill = rarity_form)
      ) +
        ggplot2::geom_col(color = "black", width = 0.7) +
        ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 0.1)) +
        ggplot2::labs(
          title = "Rare Species Abundance by Rarity Form",
          x = NULL,
          y = "Proportion of Total Community",
          fill = NULL  # Remove o título da legenda
        ) +
        ggplot2::theme_classic() +
        ggplot2::theme(
          axis.text.x = ggplot2::element_text(angle = 45, hjust = 1, face = "italic", size = 9),
          axis.text.y = ggplot2::element_text(size = 9),
          axis.title = ggplot2::element_text(size = 11),
          plot.title = ggplot2::element_text(hjust = 0.5, size = 12, face = "bold"),
          panel.grid = ggplot2::element_blank(),
          axis.line = ggplot2::element_line(color = "black"),
          legend.position = "right",
          legend.title = ggplot2::element_blank()  # Garantia extra
        )
    } else {
      p <- ggplot2::ggplot() +
        ggplot2::annotate("text", x = 1, y = 1, label = "No rare species detected") +
        ggplot2::theme_void()
    }
  }

  if (plot) print(p)

  if (verbose) {
    message("\n********************************************************************************")
    if (nrow(rare_species) > 0) {
      message("RARE SPECIES DETECTED:")
      print(rare_species[, c("species", "rarity_form", "abundance", "percentage")])
    } else {
      message("No rare species from the target list were detected.")
    }
    message("\nDATA SOURCE AND REFERENCE:")
    message("Silva, N. S., Maciel, E. A., Prado, L. P., Silva, O. G., Barbosa, D. A.,")
    message("Andrade-Silva, J., ... & Morini, M. S. (2024).")
    message("'Ant rarity and vulnerability in Brazilian Atlantic Forest fragments.'")
    message("Biological Conservation, 296, 110640.")
    message("********************************************************************************")
  }

  invisible(list(table = rare_species, plot = p))
}

#' Silva et al. (2015) Functional Guilds
#' @format A data frame with species and guild columns.
#' @source Silva, R. R., et al. (2015).
"silva_db"

#' Delabie et al. (2000) Functional Guilds
#' @format A data frame with genus and guild columns.
#' @source Delabie, J. H. C., et al. (2000).
"delabie_db"

#' AntClassify Generic Database
#' @format A data frame with genus and guild columns.
"generic_db"

#' Silvestre et al. (2003) Functional Guilds
#' @format A data frame with species/genus and guild columns.
#' @source Silvestre, R., et al. (2003).
"silvestre_db"

#' Internal datasets used by AntClassify.
#'
#' @format Data frames
#' @keywords internal
"delabie_db"

#' @rdname delabie_db
"endemic_db"

#' @rdname delabie_db
"exotic_db"

#' @rdname delabie_db
"generic_db"

#' @rdname delabie_db
"rarity_db"

#' @rdname delabie_db
"silva_db"

#' @rdname delabie_db
"silvestre_db"

---

title: "AntClassify: An R Package for Standardized Classification of Ant Communities, Functional Guilds, Endemism, and Rarity"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{AntClassify: Classification of Ant Communities}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}

---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup}
library(AntClassify)
```

## Introduction

The AntClassify package provides an integrated ecological pipeline to classify ant communities into functional guilds, identify exotic species, detect endemic and rare species of the Atlantic Forest, and quantify key ecological patterns.

This tool was developed to facilitate ecological analyses, standardize functional classification, and improve reproducibility in ant community studies. By integrating multiple ecological databases into a single workflow, AntClassify allows researchers to efficiently assess community structure, biological invasions, endemism, and rarity patterns.

The package is particularly useful for biodiversity monitoring, conservation planning, and macroecological research involving ant assemblages.

AntClassify aims to provide a standardized and reproducible framework for advancing ecological research on ant communities.

## Example dataset

```{r}
dados <- data.frame(
  Atta_sexdens = 50,
  Camponotus_atriceps = 40,
  Crematogaster_sp = 35,
  Cyphomyrmex_minutus = 30,
  Cyphomyrmex_rimosus = 28,
  Ectatomma_edentatum = 25,
  Heteroponera_mayri = 22,
  Holcoponera_striatula = 20,
  Monomorium_floricola = 18,
  Monomorium_pharaonis = 17,
  Pheidole_megacephala = 16,
  Strumigenys_emmae = 15,
  Strumigenys_rogeri = 14,
  Nylanderia_fulva = 13,
  Odontomachus_chelifer = 12,
  Oxyepoecus_reticulatus = 11,
  Pachycondyla_striata = 10,
  Apterostigma_serratum = 9,
  Brachymyrmex_delabiei = 8,
  Brachymyrmex_feitosai = 7,
  Camponotus_fallatus = 6,
  Camponotus_hermanni = 5,
  Camponotus_xanthogaster = 4,
  Pheidole_aberrans = 3,
  Pheidole_fimbriata = 3,
  Pheidole_obscurithorax = 2,
  Pheidole_subarmata = 2,
  Strumigenys_fridericimuelleri = 2,
  Heteroponera_inermis = 2,
  Oxyepoecus_browni = 2,
  Sphinctomyrmex_stali = 1,
  Strumigenys_sanctipauli = 1,
  Brachymyrmex_micromegas = 1,
  Camponotus_tripartitus = 1,
  Diaphoromyrma_sofiae = 1
)

colnames(dados) <- gsub("_", " ", colnames(dados))

dados
```

## Running the pipeline

```{r}
resultado <- antclassify(dados, validate = FALSE, plot = FALSE)
```

## Accessing results

```{r}
names(resultado)

head(resultado$guilds$table)
resultado$exotics
resultado$endemics
resultado$rarity
```

## Using individual functions

Although `antclassify()` runs the full pipeline, users can also apply each function separately depending on their research goals.

### Functional guild classification

```{r}
guilds <- assign_guild_ants(dados, validate = FALSE, plot = FALSE)

head(guilds$table)
```

### Exotic species detection

```{r}
exotics <- check_exotic_ants(dados, validate = FALSE, plot = FALSE)
exotics
```

### Endemic species (Atlantic Forest)

```{r}
endemics <- check_endemic_atlantic_ants(dados, validate = FALSE, plot = FALSE)
endemics
```

### Rarity classification

```{r}
rarity <- check_rarity_atlantic_ants(dados, validate = FALSE, plot = FALSE)
rarity
```

##Multi‑site analysis with antclassify_community

When the study involves several sampling units, the function antclassify_community() applies the full classification pipeline to each row of a community matrix and returns aggregated site‑by‑guild information. This avoids manual loops and ensures consistent classification across all sites.

The package includes a small built‑in dataset, ant_community, that can be used to test this function.

```{r}
data(ant_community)

# Run the pipeline on the built‑in dataset
res_com <- antclassify_community(ant_community, guild_col = "antclassify_guild",
                                 validate = FALSE)

# Abundance matrix (sites × guilds)
res_com$guild_abundance

# Guild richness per site
res_com$guild_richness
```

## Input data format

The package expects a community matrix where:

Rows represent sampling units (or a single community)

Columns represent species

Values represent abundance (or presence/absence)

Species names must be provided as column names..

### Example structure

The built‑in dataset ant_community demonstrates the expected format:

```{r}
data(ant_community)
ant_community
```

## Importing data from external files

### CSV files

```{r eval=FALSE}
dados <- read.csv("data.csv", check.names = FALSE)
```

### TXT files

```{r eval=FALSE}
dados <- read.table("data.txt", header = TRUE, sep = "\t", check.names = FALSE)
```

### Excel files

```{r eval=FALSE}
# install.packages("readxl")
library(readxl)

dados <- read_excel("data.xlsx")
dados <- as.data.frame(dados)
```

### Important note

```{r eval=FALSE}
colnames(dados) <- gsub("_", " ", colnames(dados))
```

This step guarantees compatibility with the internal species name standardization used in **AntClassify**.

## Final considerations

The AntClassify package provides a flexible workflow that can be used either as a fully automated pipeline or through modular functions, allowing users to adapt analyses to different ecological questions.

By integrating functional classification, invasion biology, endemism, and rarity into a single framework, the package enhances reproducibility and facilitates ecological interpretation of ant communities.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_exotic_ants.R
\name{check_exotic_ants}
\alias{check_exotic_ants}
\title{Identify Exotic Ant Species (Brazil)}
\usage{
check_exotic_ants(
  comm,
  verbose = TRUE,
  plot = TRUE,
  plot_type = c("status", "species"),
  validate = TRUE,
  delay = 0.5
)
}
\arguments{
\item{comm}{A community matrix where species are columns and samples are rows.}

\item{verbose}{Logical; if \code{TRUE}, displays progress messages.}

\item{plot}{Logical; if \code{TRUE}, displays a plot (type controlled by \code{plot_type}).}

\item{plot_type}{Character; type of plot to display. \code{"status"} (default) shows a bar plot comparing
exotic vs. native abundance proportions. \code{"species"} shows a bar plot of individual exotic species
abundances as a proportion of the total community.}

\item{validate}{Logical; if \code{TRUE}, validates species names using GBIF before analysis.}

\item{delay}{Numeric; seconds to wait between GBIF API calls when \code{validate = TRUE}.}
}
\value{
Invisibly returns a list with two elements:
\item{table}{A data frame containing exotic species detected, with columns species, abundance, and percentage.}
\item{plot}{A ggplot2 object.}
}
\description{
Checks a community matrix for known exotic ant species in Brazil sourced from Vieira (2025).
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/antclassify.R
\name{antclassify}
\alias{antclassify}
\title{AntClassify Full Ecological Pipeline}
\usage{
antclassify(comm, verbose = TRUE, plot = TRUE, validate = TRUE, delay = 0.5)
}
\arguments{
\item{comm}{Community matrix (samples x species). Species names as columns, samples as rows.}

\item{verbose}{Logical; if TRUE, displays progress messages.}

\item{plot}{Logical; if TRUE, displays guild proportion plots (passed to assign_guild_ants).}

\item{validate}{Logical; if TRUE, validates species names using GBIF.}

\item{delay}{Numeric; seconds between API calls (if validate = TRUE).}
}
\value{
A list containing results from all analyses (guilds, exotic, endemic, rarity).
}
\description{
Runs all ecological classification functions of the package.
}
\examples{
\dontrun{
# Load the built-in example dataset
data(ant_community)

# Run the full pipeline (validation disabled for speed)
results <- antclassify(ant_community, validate = FALSE, plot = FALSE)

# Inspect the results
names(results)
head(results$guilds$table)
results$exotic$table
results$endemic$table
results$rarity$table
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/assign_guild_ants.R
\name{assign_guild_ants}
\alias{assign_guild_ants}
\title{Assign Functional Guilds for Ants}
\usage{
assign_guild_ants(
  comm,
  verbose = TRUE,
  plot = TRUE,
  validate = TRUE,
  delay = 0.5
)
}
\arguments{
\item{comm}{A community matrix where species are columns and samples are rows.}

\item{verbose}{Logical; if \code{TRUE}, displays progress messages.}

\item{plot}{Logical; if \code{TRUE}, displays guild proportion plots.}

\item{validate}{Logical; if \code{TRUE}, validates species names using GBIF before analysis.}

\item{delay}{Numeric; seconds to wait between GBIF API calls when \code{validate = TRUE}.}
}
\value{
Invisibly returns a list with two elements:
\item{table}{A data frame containing species, abundance, percentage, and guild assignments from each system.}
\item{plots}{A list of four ggplot2 objects, one for each guild classification system.}
}
\description{
Classifies ants into functional guilds using four different ecological databases.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validate_species_names.R
\name{validate_species_names}
\alias{validate_species_names}
\title{Validate Species Names Using GBIF API}
\usage{
validate_species_names(comm, verbose = TRUE, delay = 0.5)
}
\arguments{
\item{comm}{A community matrix (rows = sites, columns = species).}

\item{verbose}{Logical; if TRUE, displays progress messages.}

\item{delay}{Numeric; seconds to wait between API calls (default 0.5).}
}
\value{
A community matrix with updated column names (accepted names when available).
}
\description{
Checks species names against the GBIF taxonomic backbone. If an exact match is found,
the accepted name (or canonical name) is used. If no exact match is found, the
original name is kept and a warning is issued, indicating that the name may be
outdated or misspelled.
}
\examples{
\dontrun{
data(ant_community)
comm_validated <- validate_species_names(ant_community, verbose = TRUE)
}
}

\name{ant_community}
\alias{ant_community}
\docType{data}
\title{Ant community example}
\description{
  A sample community matrix of ant species abundances with 3 sites and 6 species. Rows represent sites, columns represent species.
}
\usage{data(ant_community)}
\format{
  A data frame with 3 rows and 6 columns:
  \describe{
    \item{Atta sexdens}{abundance of \emph{Atta sexdens}}
    \item{Camponotus atriceps}{abundance of \emph{Camponotus atriceps}}
    \item{Pheidole megacephala}{abundance of \emph{Pheidole megacephala}}
    \item{Wasmannia auropunctata}{abundance of \emph{Wasmannia auropunctata}}
    \item{Solenopsis saevissima}{abundance of \emph{Solenopsis saevissima}}
    \item{Nylanderia fulva}{abundance of \emph{Nylanderia fulva}}
  }
}
\source{Simulated data for package examples.}
\examples{
data(ant_community)
head(ant_community)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_documentation.R
\docType{data}
\name{delabie_db}
\alias{delabie_db}
\alias{endemic_db}
\alias{exotic_db}
\alias{generic_db}
\alias{rarity_db}
\alias{silva_db}
\alias{silvestre_db}
\title{Internal datasets used by AntClassify.}
\format{
Data frames

An object of class \code{data.frame} with 49 rows and 2 columns.

An object of class \code{data.frame} with 19 rows and 2 columns.

An object of class \code{data.frame} with 45 rows and 2 columns.

An object of class \code{data.frame} with 120 rows and 3 columns.

An object of class \code{data.frame} with 58 rows and 2 columns.

An object of class \code{data.frame} with 66 rows and 2 columns.
}
\usage{
delabie_db

endemic_db

exotic_db

generic_db

rarity_db

silva_db

silvestre_db
}
\description{
Internal datasets used by AntClassify.
}
\keyword{datasets}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/antclassify_community.R
\name{antclassify_community}
\alias{antclassify_community}
\title{Classify Ant Communities Across Multiple Sites}
\usage{
antclassify_community(comm, guild_col = "antclassify_guild", ...)
}
\arguments{
\item{comm}{A community matrix with sites as rows and species as columns.
Species names must match the nomenclature used in the internal databases.}

\item{guild_col}{Character string giving the name of the guild column to use
for aggregation. Must be one of \code{"antclassify_guild"}, \code{"silva_guild"},
\code{"delabie_guild"}, or \code{"silvestre_guild"}. Default is
\code{"antclassify_guild"}.}

\item{...}{Additional arguments passed to \code{\link{assign_guild_ants}} (for
example, \code{validate}, \code{delay}). Note that \code{plot} is always set
to \code{FALSE} inside this function to avoid displaying one plot per site.}
}
\value{
A list with three components:
\item{by_site}{A list of length equal to \code{nrow(comm)}. Each element
contains the full output of \code{\link{assign_guild_ants}} for the
corresponding site.}
\item{guild_abundance}{A matrix of guild abundances (sites × guilds).}
\item{guild_richness}{A numeric vector of length \code{nrow(comm)} giving
the number of distinct guilds found at each site.}
}
\description{
Applies the AntClassify pipeline to each site (row) of a community matrix
and returns aggregated guild abundance and richness matrices.
}
\examples{
# Small community matrix with two sites and six species
comm <- matrix(c(5, 0, 2, 0, 1, 3,
                 2, 4, 0, 2, 0, 0),
               nrow = 2, byrow = TRUE,
               dimnames = list(c("Site1", "Site2"),
                               c("Atta sexdens", "Camponotus atriceps",
                                 "Pheidole megacephala", "Wasmannia auropunctata",
                                 "Solenopsis saevissima", "Nylanderia fulva")))

# Run the classification (validate = FALSE to avoid GBIF calls in examples)
results <- antclassify_community(comm, guild_col = "antclassify_guild",
                                 validate = FALSE)
results$guild_abundance
results$guild_richness
}
